@@ -4,7 +4,10 @@ class Collection:
         self.__item_count__ = len(items)
     
     def first(self):
-        return self.items[0]
+        try:
+            return self.items[0]
+        except Exception:
+            return None
     
     def __len__(self):
         return self.__item_count__
